@@ -5,9 +5,15 @@
 """Fabric fabfile"""
 
 
-from fabric.api import execute, hide, lcd, local, settings, task
+from __future__ import print_function
 
-from .utils import pip, requires, tobool
+from os import getcwd
+
+
+from fabric.api import abort, cd, execute, hide, hosts, lcd, local, prefix, prompt, run, settings, task
+
+
+from .utils import msg, pip, requires, tobool
 
 
 @task()
@@ -65,7 +71,6 @@ def docs(**options):
     view = tobool(options.get("view", False))
 
     with lcd("docs"):
-        pip(requirements="requirements.txt")
         local("make clean html") if clean else local("make html")
 
         if view:
@@ -81,8 +86,40 @@ def test():
 
 
 @task()
+@hosts("localhost")
 def release():
     """Performs a full release"""
 
-    local("python setup.py egg_info sdist bdist_egg register upload")
-    local("python setup.py build_sphinx upload_sphinx")
+    with cd(getcwd()):
+        with msg("Creating env"):
+            run("mkvirtualenv test")
+
+        with msg("Bootstrapping"):
+            with prefix("workon test"):
+                run("./bootstrap.sh")
+
+        with msg("Building"):
+            with prefix("workon test"):
+                run("fab develop")
+
+        with msg("Running tests"):
+            with prefix("workon test"):
+                run("fab test")
+
+        with msg("Building docs"):
+            with prefix("workon test"):
+                run("pip install -r docs/requirements.txt")
+                run("fab docs")
+
+        version = run("python setup.py --version")
+        if "dev" in version:
+            abort("Detected Development Version!")
+
+        print("Release version: {0:s}".format(version))
+
+        if prompt("Is this ok?", default="Y", validate=r"^[YyNn]?$") in "yY":
+            run("python setup.py egg_info sdist bdist_egg register upload")
+            run("python setup.py build_sphinx upload_sphinx")
+
+        with msg("Destroying env"):
+            run("rmvirtualenv test")
