@@ -4,18 +4,18 @@ from collections import OrderedDict
 from inspect import getmembers, ismethod
 
 
-import runtime
-from .states import NormalState
-from .errors import AttributeError, TypeError
-from .utils import format_object, method, Null
-from .states import BreakState, ContinueState, ReturnState
+from mio import runtime
+from mio.states import NormalState
+from mio.errors import AttributeError, TypeError
+from mio.utils import format_object, method, Null
+from mio.states import BreakState, ContinueState, ReturnState
 
 
 class Object(object):
 
     __slots__ = ("attrs", "binding", "parent", "state", "value", "traits", "behaviors",)
 
-    def __init__(self, value=Null, methods=False):
+    def __init__(self, value=Null, methods=True):
         super(Object, self).__init__()
 
         self.attrs = {}
@@ -33,10 +33,7 @@ class Object(object):
 
     def create_methods(self):
         keys = self.__class__.__dict__.keys()
-        predicate = lambda x: ismethod(x) and getattr(x, "method", False)
-        for name, method in getmembers(self, predicate):
-            if name in keys:
-                self[method.name] = method
+        self.attrs.update(((v.name, v) for k, v in getmembers(self, ismethod) if getattr(v, "method", False) and k in keys))
 
     def __hash__(self):
         return hash(self.value)
@@ -193,7 +190,7 @@ class Object(object):
 
         args = [arg for arg in args if not arg.name == "set"]
 
-        from .block import Block
+        from mio.core.block import Block
         return Block(body, args, kwargs, context)
 
     @method("method")
@@ -206,7 +203,7 @@ class Object(object):
 
         args = [arg for arg in args if not arg.name == "set"]
 
-        from .block import Block
+        from mio.core.block import Block
         return Block(body, args, kwargs)
 
     # Flow Control
@@ -310,12 +307,12 @@ class Object(object):
 
     # Object Operations
 
-    @method(":")
+    @method()
     def primitive(self, receiver, context, m, method, *args):
         method = method.name
         args = [arg.eval(context).value for arg in args]
         if hasattr(receiver, method):
-            return runtime.state.tomio(getattr(receiver, method)(*args))
+            return getattr(receiver, method)(*args)
         raise AttributeError("{0:s} has no attribute {1:s}".format(receiver.type, repr(method)))
 
     @method()
@@ -367,10 +364,6 @@ class Object(object):
 
     # Type Conversion
 
-    @method("bool")
-    def bool(self, receiver, context, m):
-        return runtime.find("True") if receiver else runtime.find("False")
-
     @method("repr")
     def repr(self, receiver, context, m):
         return runtime.find("String").clone(repr(receiver))
