@@ -4,38 +4,27 @@ from decimal import Decimal
 from traceback import format_exc
 
 
-from funcy import constantly
-
-
 from .errors import Error
 from .version import version
 from .utils import tryimport
 from .parser import parse, tokenize
 
-from .block import Block
+from .core import Core
+from .types import Types
 from .object import Object
-from .parser import Parser
-from .message import Message
-from .continuation import Continuation
-
-from .core import Boolean
-from .core import Number
-from .core import String
-from .core import List
-from .core import Dict
-from .core import FFI
-from .core import File
-from .core import Range
-from .core import System
-from .core import Module
-from .core import Importer
 
 
 def fromDict(x):
     return dict(x.value)
 
 
-def tobool(x):
+def fromBoolean(x):
+    if x.value is None:
+        return None
+    return bool(x.value)
+
+
+def toBoolean(x):
     return "True" if x else "False"
 
 
@@ -44,7 +33,7 @@ typemap = {
         dict:       "Dict",
         list:       "List",
         str:        "String",
-        bool:       tobool,
+        bool:       toBoolean,
         int:        "Number",
         type(None): "None",
         float:      "Number",
@@ -54,7 +43,7 @@ typemap = {
         "Dict":    fromDict,
         "List":    list,
         "String":  str,
-        "Boolean": bool,
+        "Boolean": fromBoolean,
         "Number":  float
     }
 }
@@ -62,12 +51,13 @@ typemap = {
 
 class State(object):
 
-    def __init__(self, args, opts, root):
+    def __init__(self, args, opts):
         super(State, self).__init__()
 
         self.args = args
         self.opts = opts
-        self.root = root
+
+        self.root = Object(methods=False)
 
     @property
     def value(self):
@@ -79,38 +69,23 @@ class State(object):
 
     def create_objects(self):
         root = self.root
-
-        object = Object(methods=True)
-
+        object = Object()
+        root.parent = object
         root["Root"] = root
         root["Object"] = object
 
-        root.parent = object
+        root["Types"] = Types()
+        root["Core"] = Core()
 
-        root["Boolean"] = Boolean()
-        root["Number"] = Number()
-        root["String"] = String()
-        root["List"] = List()
-        root["Dict"] = Dict()
+        # Bootstrap the system
+        if self.opts is None or (self.opts is not None and not self.opts.nosys):
+            self.eval("""Importer import("bootstrap")""")
 
-        root["None"] = Boolean(None)
-        root["True"] = Boolean(True)
-        root["False"] = Boolean(False)
-
-        root["Parser"] = Parser()
-        root["Message"] = Message("")
-        root["Continuation"] = Continuation()
-        root["Block"] = Block(None, [], {})
-
-        root["FFI"] = FFI()
-        root["File"] = File()
-        root["Range"] = Range()
-        root["System"] = System()
-        root["Module"] = Module()
-        root["Importer"] = Importer()
+        # Reset the last value
+        del self.root["_"]
 
     def frommio(self, x, default=None):
-        return typemap["frommio"].get(x.type, constantly(default))(x)
+        return typemap["frommio"].get(x.type, lambda x: default)(x)
 
     def tomio(self, x, default="None"):
         mapto = typemap["tomio"].get(type(x), default)
@@ -124,7 +99,14 @@ class State(object):
             return default
 
     def find(self, name):
-        return self.root[name]
+        if "Types" in self.root and name in self.root["Types"]:
+            return self.root["Types"][name]
+        elif "Core" in self.root and name in self.root["Core"]:
+            return self.root["Core"][name]
+        elif "builtins" in self.root and name in self.root["builtins"]:
+            return self.root["builtins"][name]
+        else:
+            return self.root[name]
 
     def eval(self, code, receiver=None, context=None, reraise=False):
         message = None
@@ -154,7 +136,11 @@ class State(object):
                 code = raw_input(">>> ")
                 if code:
                     result = self.eval(code)
-                    if result is not None and result.value is not None:  # pragma: no cover
-                        print("==> {0:s}".format(self.eval("repr()", receiver=result)))
+                    if result is not None:  # pragma: no cover
+                        if isinstance(result, Object):
+                            output = self.eval("repr()", receiver=result)
+                        else:
+                            output = repr(result)
+                        print("==> {0:s}".format(output))
             except EOFError:  # pragma: no cover
                 raise SystemExit(0)
