@@ -1,37 +1,34 @@
+from copy import copy
+
+
 from mio import runtime
-from mio.errors import TypeError
-from mio.utils import method, Null
-
 from mio.object import Object
-
-from number import Number
+from mio.utils import method, Null
 
 
 class List(Object):
 
-    def __init__(self, value=[]):
+    def __init__(self, value=Null):
         super(List, self).__init__(value=value)
 
         self.create_methods()
-        self.parent = runtime.state.find("Object")
+        self.parent = runtime.find("Object")
+
+    def __len__(self):
+        return len(self.value)
 
     def __iter__(self):
-        return iter(self.value)
+        return iter(self.value) if isinstance(self.value, list) else iter([])
 
     def __repr__(self):
-        values = ", ".join([repr(item) for item in self.value])
-        return "list(%s)" % values
-
-    __str__ = __repr__
+        if isinstance(self.value, list):
+            values = ", ".join([repr(item) for item in self.value])
+            return "list({0:s})".format(values)
+        return "List"
 
     @method()
-    def init(self, receiver, context, m, iterable=None):
-        if iterable is not None:
-            iterable = iterable.eval(context)
-        else:
-            iterable = runtime.find("List").clone()
-
-        receiver.value = list(iterable)
+    def init(self, receiver, context, m, l=None):
+        receiver.value = copy(l.eval(context).value) if l is not None else list()
 
     # General Operations
 
@@ -40,9 +37,14 @@ class List(Object):
         receiver.value.append(item.eval(context))
         return receiver
 
+    @method()
+    def insert(self, receiver, context, m, index, value):
+        receiver.value.insert(int(index.eval(context)), value.eval(context))
+        return receiver
+
     @method()
     def count(self, receiver, context, m, value):
-        return Number(receiver.value.count(value.eval(context)))
+        return runtime.find("Number").clone(receiver.value.count(value.eval(context)))
 
     @method()
     def extend(self, receiver, context, m, *args):
@@ -52,7 +54,7 @@ class List(Object):
 
     @method()
     def len(self, receiver, context, m):
-        return Number(len(receiver.value))
+        return runtime.find("Number").clone(len(receiver.value))
 
     @method()
     def at(self, receiver, context, m, index):
