@@ -1,10 +1,7 @@
 from mio import runtime
 from mio.utils import method
-
 from mio.object import Object
 
-from number import Number
-
 
 class String(Object):
 
@@ -12,7 +9,7 @@ class String(Object):
         super(String, self).__init__(value=value)
 
         self.create_methods()
-        self.parent = runtime.state.find("Object")
+        self.parent = runtime.find("Object")
 
     def __iter__(self):
         for c in self.value:
@@ -55,7 +52,12 @@ class String(Object):
         sub = str(sub.eval(context))
         start = int(start.eval(context)) if start is not None else None
         end = int(end.eval(context)) if end is not None else None
-        return Number(receiver.value.find(sub, start, end))
+        return runtime.find("Number").clone(receiver.value.find(sub, start, end))
+
+    @method()
+    def join(self, receiver, context, m, xs):
+        xs = xs.eval(context)
+        return receiver.clone(receiver.value.join([str(x) for x in xs]))
 
     @method()
     def lower(self, receiver, context, m):
