@@ -1,5 +1,7 @@
 import sys
-from mio.object import Object
+
+
+from mio.types.object import Object
 from mio.utils import format_method, format_object, method, tryimport, Null
 
 
@@ -26,7 +28,6 @@ FOO_TEMPLATE = """Foo at {0:s}:
 
 def test_format_object():
     foo = Foo()
-    foo.create_methods()
     assert format_object(foo) == FOO_TEMPLATE.format(hex(id(foo)))
 
 
