@@ -1,7 +1,7 @@
 def test_boolean(mio):
     assert mio.eval("Boolean").value is None
-    assert mio.eval("True").value is True
-    assert mio.eval("False").value is False
+    assert mio.eval("True")
+    assert not mio.eval("False")
     assert mio.eval("None").value is None
 
 
@@ -13,7 +13,7 @@ def test_init(mio):
 
 
 def test_repr(mio):
-    assert repr(mio.eval("Boolean")) == repr(None)
-    assert repr(mio.eval("True")) == repr(True)
-    assert repr(mio.eval("False")) == repr(False)
-    assert repr(mio.eval("None")) == repr(None)
+    assert mio.eval("Boolean repr") == repr(None)
+    assert mio.eval("True repr") == repr(True)
+    assert mio.eval("False repr") == repr(False)
+    assert mio.eval("None repr") == repr(None)
