@@ -2,6 +2,14 @@ def test_int(mio):
     assert int(mio.eval("1")) == 1
 
 
+def test_negative_int(mio):
+    assert int(mio.eval("-1")) == -1
+
+
+def test_e_int(mio):
+    assert int(mio.eval("1e3")) == 1000
+
+
 def test_int2(mio):
     assert mio.eval("1.5 int") == 1
 
@@ -10,6 +18,14 @@ def test_float(mio):
     assert float(mio.eval("1.0")) == 1.0
 
 
+def test_negative_float(mio):
+    assert float(mio.eval("-1.0")) == -1.0
+
+
+def test_e_float(mio):
+    assert float(mio.eval("1.0e3")) == 1000.0
+
+
 def test_float2(mio):
     assert mio.eval("1 float") == 1.0
 
@@ -44,3 +60,8 @@ def test_mod2(mio):
 
 def test_pow(mio):
     assert mio.eval("2 ** 4") == 16
+
+
+def test_primitive_abs(mio):
+    assert mio.eval("-1 :__abs__ == 1")
+    assert mio.eval("1 :__abs__ == 1")
